@@ -30,10 +30,14 @@ THE SOFTWARE.
 #include FT_INTERNAL_DEBUG_H
 #include FT_INTERNAL_STREAM_H
 #include FT_INTERNAL_OBJECTS_H
+#include FT_GZIP_H
+#include FT_ERRORS_H
+#include FT_BDF_H
 
 #include "pcf.h"
 #include "pcfdriver.h"
 #include "pcfutil.h"
+#include "pcfread.h"
 
 #include "pcferror.h"
 
@@ -208,6 +212,13 @@ THE SOFTWARE.
 
     FT_TRACE4(( "PCF_Face_Done: done face\n" ));
 
+    /* close gzip stream if any */
+    if ( face->root.stream == &face->gzip_stream )
+    {
+      FT_Stream_Close( &face->gzip_stream );
+      face->root.stream = face->gzip_source;
+    }
+
     return PCF_Err_Ok;
   }
 
@@ -228,7 +239,27 @@ THE SOFTWARE.
 
     error = pcf_load_font( stream, face );
     if ( error )
-      goto Fail;
+    {
+      FT_Error  error2;
+
+      /* this didn't work, try gzip support !! */
+      error2 = FT_Stream_OpenGzip( &face->gzip_stream, stream );
+      if ( error2 == FT_Err_Unimplemented_Feature )
+        goto Fail;
+
+      error = error2;
+      if ( error )
+        goto Fail;
+
+      face->gzip_source = stream;
+      face->root.stream = &face->gzip_stream;
+
+      stream = face->root.stream;
+
+      error = pcf_load_font( stream, face );
+      if ( error )
+        goto Fail;
+    }
 
     /* set-up charmap */
     {
@@ -324,7 +355,6 @@ THE SOFTWARE.
     PCF_Face    face   = (PCF_Face)FT_SIZE_FACE( size );
     FT_Stream   stream = face->root.stream;
     FT_Error    error  = PCF_Err_Ok;
-    FT_Memory   memory = FT_FACE( face )->memory;
     FT_Bitmap*  bitmap = &slot->bitmap;
     PCF_Metric  metric;
     int         bytes;
@@ -380,7 +410,8 @@ THE SOFTWARE.
     /* XXX: to do: are there cases that need repadding the bitmap? */
     bytes = bitmap->pitch * bitmap->rows;
 
-    if ( FT_ALLOC( bitmap->buffer, bytes ) )
+    error = ft_glyphslot_alloc_bitmap( slot, bytes );
+    if ( error )
       goto Exit;
 
     if ( FT_STREAM_SEEK( metric->bits )          ||
@@ -420,7 +451,6 @@ THE SOFTWARE.
 
     slot->linearHoriAdvance = (FT_Fixed)bitmap->width << 16;
     slot->format            = FT_GLYPH_FORMAT_BITMAP;
-    slot->flags             = FT_GLYPH_OWN_BITMAP;
 
     FT_TRACE4(( " --- ok\n" ));
 
@@ -429,6 +459,49 @@ THE SOFTWARE.
   }
 
 
+  static FT_Error
+  pcf_get_bdf_property( PCF_Face          face,
+                        const char*       prop_name,
+                        BDF_PropertyRec  *aproperty )
+  {
+    PCF_Property   prop;
+
+    prop = pcf_find_property( face, prop_name );
+    if ( prop != NULL )
+    {
+      if ( prop->isString )
+      {
+        aproperty->type   = BDF_PROPERTY_TYPE_ATOM;
+        aproperty->u.atom = prop->value.atom;
+      }
+      else
+      {
+       /* apparently, the PCF driver loads all properties as signed integers !
+        * this really doesn't seem to be a problem, because this is
+        * sufficient for any meaningful values
+        */
+        aproperty->type      = BDF_PROPERTY_TYPE_INTEGER;
+        aproperty->u.integer = prop->value.integer;
+      }
+      return 0;
+    }
+    return FT_Err_Invalid_Argument;
+  }
+
+
+  static FT_Module_Interface
+  pcf_driver_requester( FT_Module    module,
+                        const char*  name )
+  {
+    FT_UNUSED( module );
+
+    if ( name && ft_strcmp( name, "get_bdf_property" ) == 0 )
+      return (FT_Module_Interface) pcf_get_bdf_property;
+
+    return NULL;
+  }
+
+
   FT_CALLBACK_TABLE_DEF
   const FT_Driver_ClassRec  pcf_driver_class =
   {
@@ -444,7 +517,7 @@ THE SOFTWARE.
 
       (FT_Module_Constructor)0,
       (FT_Module_Destructor) 0,
-      (FT_Module_Requester)  0
+      (FT_Module_Requester)  pcf_driver_requester
     },
 
     sizeof( PCF_FaceRec ),
